@@ -157,6 +157,9 @@ class Vehicle(object):
             result["expiry_time"] = self.accessTokenExpiresAt
             result["expiry_date"] = time.localtime(self.accessTokenExpiresAt)
             self.writeToken(result)
+        elif response.status_code == 400:
+            _LOGGER.debug("400 response while refreshing token. Token has Expired. Re-Authorizing Now...")
+            self.auth()
         elif response.status_code == 401:
             _LOGGER.debug("401 response while refreshing token")
             self.auth()
